function [X,J,C] = lqrsim(Avec,Bvec,Fvec,Qvec,Lvec,Rvec,P,x0,th0,n,s);

%LQRSIM	Simulation of the closed loop system with LQR for Markov systems
%
%	Usage:
%		[X,J,C] = lqrsim(Avec,Bvec,Fvec,Qvec,Lvec,Rvec,P,X0,TH0,N,S);
%
%	X contains the history of the system state (time increasing columnwise)
%	and J is an estimation for the quadratic cost. C contains the
%	realization for the Markov chain.
%
%	Gvec,...,Rvec contain the system and cost descriptions, P is the
%	probability transition matrix, X0 and TH0 are the initial conditions
%	for the system and for the Markov chain. N is the number of steps
%	for the simulation, and S (optional) is the seed for the random
%	number generator.

%	Version 1.0
%	RP Marques	(11/03/97)

% Argument checking
if nargin==10,
	s = sum(100*clock);
elseif s==[],
	s = sum(100*clock);
end;
rand('seed',s);

if size(P,1)==size(P,2),
	N=size(P,1);
else
	error('Invalid Transition Probability Matrix');
end;

if th0 > N | th0 < 1
	error('Invalid initial state');
end;

% Argument unpacking
Gvec = cloopvec(Avec,Bvec,Fvec);
for i=1:N
	istr=int2str(i);
	eval(['G',istr,'=unstack(Gvec,',istr,');']);
	eval(['F',istr,'=unstack(Fvec,',istr,');']);
	eval(['Q',istr,'=unstack(Qvec,',istr,');']);
	eval(['L',istr,'=unstack(Lvec,',istr,');']);
	eval(['R',istr,'=unstack(Rvec,',istr,');']);
end;

% Initialization
dimX=size(G1,1); X=zeros(dimX,n+1); X(:,1)=x0;
Jaux = zeros(n,1);
C = mkvchain(P,th0,n,s);

% Simulation
for i=1:n
	thstr=int2str(C(i));
	eval(['X(:,i+1)=G',thstr,'*X(:,i);']);
	eval(['XU=[X(:,i);F',thstr,'*X(:,i)];']);
	eval(['M=[Q',thstr,' L',thstr,';L',thstr,''' R',thstr,'];']);
	Jaux(i) = XU'*M*XU;
end;

% Conclusion

J = 0.5*sum(Jaux);
X(:,n+1)=[];