function C = mkvchain(P,ic,n,s);

%MKVCHAIN Generates a realization for a Markov chain
%
%	Usage:
%		C = mkvchain(P,IC,N,S);
%
%	where C is the Markov chain realization, P is the transition
%	probability matrix, IC is the initial state for the Markov
%	chain, N is the length of the realization and S (optional) is
%	the seed for the random number generator.

%	Version 1.0
%	RP Marques	(11/03/97);

% Argument checking
if nargin == 3,
	s = sum(100*clock);
elseif s == [],
	s = sum(100*clock);
end;
rand('seed',s);

if size(P,1)==size(P,2),
	N=size(P,1);
else
	error('Invalid Transition Probability Matrix');
end;

if ic>N | ic<1
	error('Invalid initial state');
end;


% Initialization
C=zeros(n,1); C(1)=ic; Psum=cumsum(P')'; raux=rand(n,1);

% Realization generation
for i=2:n,
	aux=find(Psum(C(i-1),:)>=raux(i));
	C(i)=aux(1);
end;




