function [M1,M2,M3,M4,M5,M6,M7,M8,M9,M10,M11,M12,M13,M14,M15,M16] = ...
unstack(x,index)
% function [M1,...,M15] = unstack(x,index)
% UNSTACK extracts matrices stored in vector with special format.
% inputs:
% x	    a matrix, or a colum vector formed using stack,
%	    possibly recursively, as in
%		x = stack(M1,stack(M2,M3),[],M4).
% index	    integer vector containing a subset of {1,...,15}.
% outputs:
% M1,...,M15 matrices stored in x (M1 equals x if x is not a stack 
%	    vector, and M2,...,M15 are empty).
% see also:
%  stack, reshape.

% x may contain embedded stack vectors
%[x,szs,matnum] = stack2vec(x);
%x = [NaN; matnum; szs; x];

% drop first element of x
x = x(2:length(x));

% find number of matrices, and row, col info
matnum = x(1);
rows = x(2:2:2*matnum+1);
cols = x(3:2:2*matnum+2);

% case when index is not specified
if nargin == 1, index = 1:matnum; end

% check compatibility of index vector
if any(index > matnum), 
  error(' Index exceeds stack dimension.'); 
end  

% extract matrices
for i = 1:length(index),
  indi = index(i);
  addr = 1+2*matnum+rows(1:indi)'*cols(1:indi);
  addr = addr-rows(indi)*cols(indi);
  addr = addr+1:addr+rows(indi)*cols(indi);
  mtrx = reshape(x(addr),rows(indi),cols(indi));
  eval([sprintf('M%1.0f',i) '= mtrx;']);
end
